@@ -1,4 +1,4 @@
 
 class Function:
-    def invoke(self):
+    def invoke(self, filename):
         return "<!-- FUNCTION NOT IMPLEMENTED -->"
